spannertools.DuratedComplexBeam
===============================

.. abjad-lineage:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam

.. autoclass:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.append
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.append_left
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.components
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.detach
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.direction
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.durations
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.extend
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.extend_left
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.fracture
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.fuse
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.get_duration
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.get_timespan
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.index
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.is_beamable_component
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.leaves
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.lone
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.pop
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.pop_left
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.span
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__contains__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__copy__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__eq__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__format__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__getitem__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__len__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__lt__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__ne__
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__repr__

Bases
-----

- :py:class:`spannertools.ComplexBeam <abjad.tools.spannertools.ComplexBeam.ComplexBeam>`

- :py:class:`spannertools.Beam <abjad.tools.spannertools.Beam.Beam>`

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.leaves
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.durations
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.lone
   :noindex:

.. autoattribute:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.span
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.append
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.index
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.pop_left
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.is_beamable_component
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam.__repr__
   :noindex:
